# My Terminal AI

My Terminal AI is a Python-based terminal assistant that can execute system commands, provide general information, and interact with an LLaMA model via Ollama.

## Installation

To install, use pip:

